# ShanCsv <br/>[![Python 3.8+](https://img.shields.io/badge/python-3.8%2B-blue)](https://www.python.org/downloads/) [![Pip latest](https://img.shields.io/badge/pip-latest-blue)](https://pip.pypa.io/en/stable/) [![license](https://img.shields.io/badge/license-MIT-green)](https://github.com/Ninjago77/ShanCsv/blob/main/LICENSE)
A [Python Package](https://pypi.org/) for [CSV](https://en.wikipedia.org/wiki/Comma-separated_values) File Parsing and Rendering. Easy to use and follows the formats of other commonly used libraries - The [load(s)](#shancsvloadfile)/[dump(s)](#shancsvdumpdata-file) functions of [pickle](https://docs.python.org/3/library/pickle.html)/[json](https://docs.python.org/3/library/json.html). Automatically converts data values from/to a 2-dimensional list as *float, int, bool, none, str* unlike the [in-built csv library.](https://docs.python.org/3/library/csv.html)
Completly customizable by giving the specified \*\**kwargs* to the [`Csv Class`](#shancsvcsvinputobj-inputtypestr-moreargs) directly or through the [other functions](#basic-usage) indirectly. Simple, readable, easy to understand [Docs.](https://github.com/Ninjago77/ShanCsv#readme) So what are you waiting for? Install [ShanCsv](#how-to-install) and try it now!
## View the [Docs](https://github.com/Ninjago77/ShanCsv#readme) and more at: https://github.com/Ninjago77/ShanCsv#readme